@@ -141,6 +141,7 @@ class InvoiceState(Enum):
 class WaldurClient(object):
     class Endpoints(object):
         ComponentUsage = "marketplace-component-usages"
+        Configuration = "configuration"
         CustomerPermissions = "customer-permissions"
         Customers = "customers"
         Flavor = "openstacktenant-flavors"
@@ -151,7 +152,7 @@ class WaldurClient(object):
         Invoice = "invoices"
         InvoiceItems = "invoice-items"
         MarketplaceCategories = "marketplace-categories"
-        MarketplaceOffering = "marketplace-offerings"
+        MarketplaceProviderOffering = "marketplace-provider-offerings"
         MarketplaceOrder = "marketplace-orders"
         MarketplaceOrderItem = "marketplace-order-items"
         MarketplacePlan = "marketplace-plans"
@@ -424,6 +425,9 @@ class WaldurClient(object):
     def _get_project(self, identifier):
         return self._get_resource(self.Endpoints.Project, identifier)
 
+    def get_configuration(self):
+        return self._query_resource_list(self.Endpoints.Configuration, {})
+
     def get_user(self, identifier):
         return self._get_resource(self.Endpoints.Users, identifier)
 
@@ -826,6 +830,11 @@ class WaldurClient(object):
         )
         return self._get(url, valid_states=[200])
 
+    def update_marketplace_resource(self, resource_uuid: str, **kwargs):
+        return self._patch_resource(
+            self.Endpoints.MarketplaceResources, resource_uuid, kwargs
+        )
+
     def get_instance_via_marketplace(self, name, project=None):
         """Get an openstack instance via marketplace.
 
@@ -1451,11 +1460,14 @@ class WaldurClient(object):
 
         else:
             resource = self._create_resource(
-                self.Endpoints.MarketplaceOffering, payload=params
+                self.Endpoints.MarketplaceProviderOffering, payload=params
             )
 
             return resource, True
 
+    def get_customer(self, identifier, filters=None):
+        return self._get_resource(self.Endpoints.Customers, identifier, filters)
+
     def list_customers(self, filters=None):
         return self._query_resource_list(self.Endpoints.Customers, filters)
 
@@ -1564,12 +1576,24 @@ class WaldurClient(object):
             return self._delete_resource(self.Endpoints.Project, project)
         return self._delete_resource_by_url(project)
 
-    def list_marketplace_offerings(self, filters=None):
-        return self._query_resource_list(self.Endpoints.MarketplaceOffering, filters)
+    def list_marketplace_provider_offerings(self, filters=None):
+        return self._query_resource_list(
+            self.Endpoints.MarketplaceProviderOffering, filters
+        )
 
-    def get_marketplace_offering(self, offering_uuid):
+    def list_marketplace_public_offerings(self, filters=None):
+        return self._query_resource_list(
+            self.Endpoints.MarketplacePublicOffering, filters
+        )
+
+    def get_marketplace_provider_offering(self, offering_uuid):
         return self._query_resource_by_uuid(
-            self.Endpoints.MarketplaceOffering, offering_uuid
+            self.Endpoints.MarketplaceProviderOffering, offering_uuid
+        )
+
+    def get_marketplace_public_offering(self, offering_uuid):
+        return self._query_resource_by_uuid(
+            self.Endpoints.MarketplacePublicOffering, offering_uuid
         )
 
     def marketplace_resource_create_order(
@@ -1585,7 +1609,7 @@ class WaldurClient(object):
         limits = limits or {}
         order_item = {
             "offering": self._build_resource_url(
-                self.Endpoints.MarketplaceOffering, offering_uuid
+                self.Endpoints.MarketplacePublicOffering, offering_uuid
             ),
             "attributes": attributes,
             "limits": limits,
@@ -1804,7 +1828,7 @@ class WaldurClient(object):
             {
                 "user": self._build_resource_url(self.Endpoints.Users, user_uuid),
                 "offering": self._build_resource_url(
-                    self.Endpoints.MarketplaceOffering, offering_uuid
+                    self.Endpoints.MarketplaceProviderOffering, offering_uuid
                 ),
             },
         )
@@ -1843,7 +1867,7 @@ class WaldurClient(object):
     ):
         if is_uuid(offering):
             offering = self._build_resource_url(
-                self.Endpoints.MarketplaceOffering, offering
+                self.Endpoints.MarketplaceProviderOffering, offering
             )
 
         if is_uuid(user):
@@ -1988,7 +2012,9 @@ class WaldurClient(object):
         self, offering_uuid: str, components: List[OfferingComponent]
     ):
         url = self._build_resource_url(
-            self.Endpoints.MarketplaceOffering, offering_uuid, "update_components"
+            self.Endpoints.MarketplaceProviderOffering,
+            offering_uuid,
+            "update_components",
         )
         components_json = [
             {
